﻿Function Install-GPAAAuditService {
#This function installs the GPAA Audit Service 3.0 on a domain controller
#Written by SDM Software, April 2020
#The associated zip file should contain the customized gpauditservice.exe.config file for your environment
#GPAuditServicev1.zip is used for 2008-R2 DCs and GPAuditServicev2.zip for 2012-R2 and greater
#modify the installDir variable if needed to change the install directory for your environment
#You can optionally pass a PSCredential object (get-credential) to the function if you want to use a service account to run the service

#copy this PowerShell script and the associated zip file to a temp directory on your DC, then execute this script

[cmdletbinding()]
Param (

[System.Management.Automation.PSCredential]
$ServiceAccount

)


[string]$installDir = "$env:ProgramFiles\SDM Software\SDM GPAA Audit Service"
[string]$osVersion = (Get-WmiObject -Query 'Select Version FROM Win32_OperatingSystem').Version
$GPAA_SERVICE = 'SDMGPAAAudit'

#create install folders
Write-Host -Object 'Creating Folder Structure'
New-Item $installDir -ItemType directory 
New-Item "$env:ProgramData\SDM Software\GPAA\Current" -ItemType directory
New-Item "$env:ProgramData\SDM Software\GPAA\GPBackups" -ItemType directory
New-Item "$env:ProgramData\SDM Software\GPAA\WMI" -ItemType directory

#now create reg values
Write-Host -Object 'Creating Registry Keys'
New-Item -Path "HKLM:\Software\SDM Software"
New-Item -Path "HKLM:\Software\SDM Software\GPAA"
New-ItemProperty -Path "HKLM:\SOFTWARE\SDM Software\GPAA" -Name InstallDir -PropertyType String -Value $installDir
New-ItemProperty -Path "HKLM:\SOFTWARE\SDM Software\GPAA" -Name EnableTraceLogging -PropertyType DWord -Value 0

Switch($osVersion)
{
	#Based on OS Version, extract the right Binaries to the InstallDir
	6.1.7601 
		{ 
			Write-Host -Object 'Extracting 2008 R2 Binaries'
            Expand-Archive -Path ".\GPAuditServicev1.zip" -DestinationPath "$installDir"
			#now install the service
			Write-Host -Object 'Installing 2008 R2 SDMGPAAAudit Service'
            if ($ServiceAccount -ne $null)
            {
			    New-Service -Name $GPAA_SERVICE -DisplayName 'SDM Software GPAA Auditing Service' -StartupType Automatic -BinaryPathName "$installDir\GPAuditService7.exe" -Credential $ServiceAccount -Description 'Provides Group Policy Auditing for SDM Software GPAA Product'
            }
            else
            {
                New-Service -Name $GPAA_SERVICE -DisplayName 'SDM Software GPAA Auditing Service' -StartupType Automatic -BinaryPathName "$installDir\GPAuditService7.exe" -Description 'Provides Group Policy Auditing for SDM Software GPAA Product'
            }

		}
	Default 
		{ 
			Write-Host -Object 'Extracting 2012 R2 and Later Binaries'
            Expand-Archive -Path ".\GPAuditServicev2.zip" -DestinationPath "$installDir"			
			#now install the service
			Write-Host -Object 'Installing 2012 R2 or Later SDMGPAAAudit Service'
            if ($ServiceAccount -ne $null)
            {
			    New-Service -Name $GPAA_SERVICE -DisplayName 'SDM Software GPAA Auditing Service' -StartupType Automatic -BinaryPathName "$installDir\GPAuditService.exe" -Credential $ServiceAccount -Description 'Provides Group Policy Auditing for SDM Software GPAA Product'
            }
            else
            {
                New-Service -Name $GPAA_SERVICE -DisplayName 'SDM Software GPAA Auditing Service' -StartupType Automatic -BinaryPathName "$installDir\GPAuditService.exe" -Description 'Provides Group Policy Auditing for SDM Software GPAA Product'
            }
		}
}

#Start and Validate
Write-Host -Object 'Starting SDM GPAA Service'
Start-Service -Name $GPAA_SERVICE
Get-Service -Name $GPAA_SERVICE -ErrorAction SilentlyContinue | %{ if($_.Status -eq 'Running') { Write-Host -Object "$GPAA_SERVICE Running" } else { Write-Host -Object "$GPAA_SERVICE Stopped"; Exit 4}}


}

#uncomment this next line if you plan to install the service with a service account. You'll need to assign a credential to the $cred value
#Install-GPAAAuditService -ServiceAccount $cred
Install-GPAAAuditService



# SIG # Begin signature block
# MIIL7AYJKoZIhvcNAQcCoIIL3TCCC9kCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQU07gK+g/ddvMB5Cb7yRknDwOR
# kU6ggglVMIIEmTCCA4GgAwIBAgIQcaC3NpXdsa/COyuaGO5UyzANBgkqhkiG9w0B
# AQsFADCBqTELMAkGA1UEBhMCVVMxFTATBgNVBAoTDHRoYXd0ZSwgSW5jLjEoMCYG
# A1UECxMfQ2VydGlmaWNhdGlvbiBTZXJ2aWNlcyBEaXZpc2lvbjE4MDYGA1UECxMv
# KGMpIDIwMDYgdGhhd3RlLCBJbmMuIC0gRm9yIGF1dGhvcml6ZWQgdXNlIG9ubHkx
# HzAdBgNVBAMTFnRoYXd0ZSBQcmltYXJ5IFJvb3QgQ0EwHhcNMTMxMjEwMDAwMDAw
# WhcNMjMxMjA5MjM1OTU5WjBMMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMdGhhd3Rl
# LCBJbmMuMSYwJAYDVQQDEx10aGF3dGUgU0hBMjU2IENvZGUgU2lnbmluZyBDQTCC
# ASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAJtVAkwXBenQZsP8KK3TwP7v
# 4Ol+1B72qhuRRv31Fu2YB1P6uocbfZ4fASerudJnyrcQJVP0476bkLjtI1xC72Ql
# WOWIIhq+9ceu9b6KsRERkxoiqXRpwXS2aIengzD5ZPGx4zg+9NbB/BL+c1cXNVeK
# 3VCNA/hmzcp2gxPI1w5xHeRjyboX+NG55IjSLCjIISANQbcL4i/CgOaIe1Nsw0Rj
# gX9oR4wrKs9b9IxJYbpphf1rAHgFJmkTMIA4TvFaVcnFUNaqOIlHQ1z+TXOlScWT
# af53lpqv84wOV7oz2Q7GQtMDd8S7Oa2R+fP3llw6ZKbtJ1fB6EDzU/K+KTT+X/kC
# AwEAAaOCARcwggETMC8GCCsGAQUFBwEBBCMwITAfBggrBgEFBQcwAYYTaHR0cDov
# L3QyLnN5bWNiLmNvbTASBgNVHRMBAf8ECDAGAQH/AgEAMDIGA1UdHwQrMCkwJ6Al
# oCOGIWh0dHA6Ly90MS5zeW1jYi5jb20vVGhhd3RlUENBLmNybDAdBgNVHSUEFjAU
# BggrBgEFBQcDAgYIKwYBBQUHAwMwDgYDVR0PAQH/BAQDAgEGMCkGA1UdEQQiMCCk
# HjAcMRowGAYDVQQDExFTeW1hbnRlY1BLSS0xLTU2ODAdBgNVHQ4EFgQUV4abVLi+
# pimK5PbC4hMYiYXN3LcwHwYDVR0jBBgwFoAUe1tFz6/Oy3r9MZIaarbzRutXSFAw
# DQYJKoZIhvcNAQELBQADggEBACQ79degNhPHQ/7wCYdo0ZgxbhLkPx4flntrTB6H
# novFbKOxDHtQktWBnLGPLCm37vmRBbmOQfEs9tBZLZjgueqAAUdAlbg9nQO9ebs1
# tq2cTCf2Z0UQycW8h05Ve9KHu93cMO/G1GzMmTVtHOBg081ojylZS4mWCEbJjvx1
# T8XcCcxOJ4tEzQe8rATgtTOlh5/03XMMkeoSgW/jdfAetZNsRBfVPpfJvQcsVncf
# hd1G6L/eLIGUo/flt6fBN591ylV3TV42KcqF2EVBcld1wHlb+jQQBm1kIEK3Osgf
# HUZkAl/GR77wxDooVNr2Hk+aohlDpG9J+PxeQiAohItHIG4wggS0MIIDnKADAgEC
# AhA1gMUgFAPkyEx4e4mScoolMA0GCSqGSIb3DQEBCwUAMEwxCzAJBgNVBAYTAlVT
# MRUwEwYDVQQKEwx0aGF3dGUsIEluYy4xJjAkBgNVBAMTHXRoYXd0ZSBTSEEyNTYg
# Q29kZSBTaWduaW5nIENBMB4XDTE5MTIxNzAwMDAwMFoXDTIxMTIxNTIzNTk1OVow
# cjELMAkGA1UEBhMCVVMxEzARBgNVBAgMCkNhbGlmb3JuaWExFDASBgNVBAcMC1Nh
# biBBbnNlbG1vMRswGQYDVQQKDBJTRE0gU29mdHdhcmUsIEluYy4xGzAZBgNVBAMM
# ElNETSBTb2Z0d2FyZSwgSW5jLjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoC
# ggEBAMVHr7hzA4jv3jkHiybLABaeQ5BetOpLi5eraFLQUkkgi9F0DReK7DTQRONq
# 9SQb4UMfFD3Co8/j8QorkyiF0IVLjDQ760v/PyuEXaToTgP9e0f6JVzFITSKUjsc
# cz43xqppZvVqOB7p7Xldgc0iIvEHI3r4a2y0Hr9ooSnvMw5QJ1wD42G/3huho6f9
# ynPHwNuLiIYt6Act03lOYA0kKWVpJVULICyfLI/0Idr74PSjjL+zIxSHqQse//Yf
# TK2/VMZ0EQDaNVt9RCT5dz5JujNbugaXyCl6VaaqlaH1uY0+7otrCTeHiD5KcA32
# 8KL7H0zdBQCYXwbwml1wxPTEl4ECAwEAAaOCAWowggFmMAkGA1UdEwQCMAAwHwYD
# VR0jBBgwFoAUV4abVLi+pimK5PbC4hMYiYXN3LcwHQYDVR0OBBYEFGH88KVcg7n5
# FvrR1cWk+ZEbi17GMCsGA1UdHwQkMCIwIKAeoByGGmh0dHA6Ly90bC5zeW1jYi5j
# b20vdGwuY3JsMA4GA1UdDwEB/wQEAwIHgDATBgNVHSUEDDAKBggrBgEFBQcDAzBu
# BgNVHSAEZzBlMGMGBmeBDAEEATBZMCYGCCsGAQUFBwIBFhpodHRwczovL3d3dy50
# aGF3dGUuY29tL2NwczAvBggrBgEFBQcCAjAjDCFodHRwczovL3d3dy50aGF3dGUu
# Y29tL3JlcG9zaXRvcnkwVwYIKwYBBQUHAQEESzBJMB8GCCsGAQUFBzABhhNodHRw
# Oi8vdGwuc3ltY2QuY29tMCYGCCsGAQUFBzAChhpodHRwOi8vdGwuc3ltY2IuY29t
# L3RsLmNydDANBgkqhkiG9w0BAQsFAAOCAQEABjY0ODWoUEaaaq58IgHniVkS2BEy
# XormIR5FqHIFNdWZ+9LIVbeCV26I9ZlnSIQdZ//Cv+GMMbbf79fuIZw2ltoqFnnp
# m/cuxs7rp5yx998ZOytup9sIwMuStyPKUrxpp496QQGj2BhH2D1/wVCNTwsJrMK7
# 4Wp+2pkArUYAFBpYIb/ZuR5ikAYBejXe2FZdtsm5M/mIDLYyImctry1ipVvugT0W
# ycKgnNn/OPLu343A5obmyu0aPIbTE8hZDdf8jCp3rUeldoXIjaBE5QxXOu+hvQuA
# Xd0XgrzXc8GnfhwVBLpkbN389DHhcKQtsqFBATmLIrLuY6A5q05dIY/hKjGCAgEw
# ggH9AgEBMGAwTDELMAkGA1UEBhMCVVMxFTATBgNVBAoTDHRoYXd0ZSwgSW5jLjEm
# MCQGA1UEAxMddGhhd3RlIFNIQTI1NiBDb2RlIFNpZ25pbmcgQ0ECEDWAxSAUA+TI
# THh7iZJyiiUwCQYFKw4DAhoFAKB4MBgGCisGAQQBgjcCAQwxCjAIoAKAAKECgAAw
# GQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisG
# AQQBgjcCARUwIwYJKoZIhvcNAQkEMRYEFIupNOtxM/qLpQ4fwhqgZ0QnqfAWMA0G
# CSqGSIb3DQEBAQUABIIBAJwEbJZERqxlgavOSg6AQAk6wT8Bouy6IqtUkDnvy7CI
# iuMdhl0c+jfNIxPyUGGFSLHGR3cwwcxEGFsg3YPlensbCJkUwHfW+VvS/RknWLOy
# 6tQWi+dGzyUY0hzTApcM8p3OuuFnsILcjeJFcOVCAdU8B/yj13jdpUlwxSmEOVns
# 92HNQK/9q9QRuuiVJcWtuzY2AM+S/EW3n7QGRgoBXn1iKa4M0l7TKeVyH+cT5FL2
# 1+2LIFE0yOr+vgDaM9aJfhsNBTx+etK3Jlmivy4WesJPH1g0Vg19OovjDwhF6reu
# jy9EEWaRj7S2khPJdCR4293w0xqJu1k671ZfZTIZwhI=
# SIG # End signature block
